@@ -268,6 +268,8 @@ void KToolBar::Private::init(bool readConfig, bool _isMainToolBar)
         q->setMovable(!KToolBar::toolBarsLocked());
     }
 
+    q->toggleViewAction()->setEnabled(KAuthorized::authorizeKAction(QStringLiteral("options_show_toolbar")));
+
     connect(q, SIGNAL(movableChanged(bool)),
             q, SLOT(slotMovableChanged(bool)));
 
@@ -1041,11 +1043,11 @@ void KToolBar::saveState(QDomElement &current) const
 {
     Q_ASSERT(!current.isNull());
 
-    current.setAttribute(QStringLiteral("tempXml"), QLatin1String("true"));
+    current.setAttribute(QStringLiteral("tempXml"), QStringLiteral("true"));
 
-    current.setAttribute(QStringLiteral("noMerge"), QLatin1String("1"));
+    current.setAttribute(QStringLiteral("noMerge"), QStringLiteral("1"));
     current.setAttribute(QStringLiteral("position"), d->getPositionAsString().toLower());
-    current.setAttribute(QStringLiteral("hidden"), isHidden() ? QLatin1String("true") : QLatin1String("false"));
+    current.setAttribute(QStringLiteral("hidden"), isHidden() ? QStringLiteral("true") : QStringLiteral("false"));
 
     const int currentIconSize = iconSize().width();
     if (currentIconSize == d->iconSizeSettings.defaultValue()) {
